@@ -8,5 +8,9 @@ Copyright (c) 2011 Objects in Space and Time. All rights reserved.
 
 """
 __author__ = 'Alexander Bohn'
-__version__ = (0, 2, 6)
-__doc__ = 'Automatic delegate methods for Django managers and querysets without runtime dispatch penalties.'
\ No newline at end of file
+__email__ = 'fish2000@gmail.com'
+__version__ = (0, 2, 7)
+__doc__ = '''
+Automatic delegate methods for Django managers and querysets,
+without runtime dispatch penalties.
+'''
\ No newline at end of file
